@@ -18,11 +18,11 @@ Text::Amuse::Preprocessor - Helpers for Text::Amuse document formatting.
 
 =head1 VERSION
 
-Version 0.41
+Version 0.50
 
 =cut
 
-our $VERSION = '0.41';
+our $VERSION = '0.50';
 
 
 =head1 SYNOPSIS
@@ -426,7 +426,7 @@ sub _set_infile {
         }
     }
     else {
-        File::Copy::copy($input, $infile) or die "Couldn't copy $input to $infile";
+        File::Copy::copy($input, $infile) or die "Couldn't copy $input to $infile $!";
         $self->_infile($infile);
     }
     return $self->_infile;
